import { useEffect, useRef } from "react";
import { Enums, RenderingEngine } from "@cornerstonejs/core";
import initDemo from "./init.demo";
import createImageIdsAndCacheMetaData from "./createImageIdsAndCacheMetaData";
import {
  IStackViewport,
  PublicViewportInput,
} from "@cornerstonejs/core/dist/types/types";

interface VolumeViewerProps {
  children?: JSX.Element;
}

const renderingEngineId = "myRenderingEngine";
const viewportId = "CT_STACK";

const { ViewportType } = Enums;

const StudyInstanceUID =
  "1.2.840.113564.345049290535.9692.637552042156233117.433089";
const SeriesInstanceUID =
  "1.3.12.2.1107.5.1.4.76315.30000021042706150001900118311";

export const VolumeViewer = (props: VolumeViewerProps) => {
  const dicomRef = useRef(null);

  const run = async () => {
    await initDemo();
    // Get Cornerstone imageIds and fetch metadata into RAM
    const imageIds = await createImageIdsAndCacheMetaData({
      StudyInstanceUID,
      SeriesInstanceUID,
      wadoRsRoot: "/dicom-web",
    });

    console.log(imageIds)

    const renderingEngine = new RenderingEngine(renderingEngineId);

    const viewportInput = {
      viewportId,
      type: ViewportType.STACK,
      element: dicomRef.current,
    } as unknown as PublicViewportInput;

    renderingEngine.enableElement(viewportInput);

    const viewport = renderingEngine.getViewport(viewportId) as IStackViewport;

    const stack = imageIds;

    await viewport.setStack(stack);

    viewport.render();
  };

  useEffect(() => {
    run();
  }, []);

  return (
    <div>
      <div ref={dicomRef} style={{ width: 200, height: 200 }}></div>
    </div>
  );
};
